@@ -23,8 +23,8 @@ from distributed.bokeh.worker import (BokehWorker, StateTable, CrossFilter,
 @gen_cluster(client=True,
              worker_kwargs={'services': {('bokeh', 0):  BokehWorker}})
 def test_simple(c, s, a, b):
-    assert s.worker_info[a.address]['services'] == {'bokeh': a.services['bokeh'].port}
-    assert s.worker_info[b.address]['services'] == {'bokeh': b.services['bokeh'].port}
+    assert s.workers[a.address].services == {'bokeh': a.services['bokeh'].port}
+    assert s.workers[b.address].services == {'bokeh': b.services['bokeh'].port}
 
     future = c.submit(sleep, 1)
     yield gen.sleep(0.1)
@@ -39,7 +39,7 @@ def test_simple(c, s, a, b):
 @gen_cluster(client=True,
              worker_kwargs={'services': {('bokeh', 0):  (BokehWorker, {})}})
 def test_services_kwargs(c, s, a, b):
-    assert s.worker_info[a.address]['services'] == {'bokeh': a.services['bokeh'].port}
+    assert s.workers[a.address].services == {'bokeh': a.services['bokeh'].port}
     assert isinstance(a.services['bokeh'], BokehWorker)
 
 
@@ -120,17 +120,15 @@ def test_CommunicatingStream(c, s, a, b):
             len(first(bb.incoming.data.values())))
 
 
-@pytest.mark.skipif(sys.version_info[0] == 2,
-                    reason='https://github.com/bokeh/bokeh/issues/5494')
-@gen_cluster(client=True)
-def test_port_overlap(c, s, a, b):
-    sa = BokehWorker(a)
-    sa.listen(57384)
-    sb = BokehWorker(b)
-    sb.listen(57384)
-    assert sa.port
-    assert sb.port
-    assert sa.port != sb.port
+@gen_cluster(client=True,
+             check_new_threads=False,
+             worker_kwargs={'services': {('bokeh', 0):  BokehWorker}})
+def test_prometheus(c, s, a, b):
+    pytest.importorskip('prometheus_client')
+    assert s.workers[a.address].services == {'bokeh': a.services['bokeh'].port}
 
-    sa.stop()
-    sb.stop()
+    http_client = AsyncHTTPClient()
+    for suffix in ['metrics']:
+        response = yield http_client.fetch('http://localhost:%d/%s'
+                                           % (a.services['bokeh'].port, suffix))
+        assert response.code == 200
